@@ -10,7 +10,7 @@
  * terminal, so we try to use a lockfile if terminal locking doesn't work,
  * and finally abort if even that is unavailable.
  *
- * Copyright 2002-2008, 2010, 2012-2015, 2017, 2021, 2023 Andrew Wood
+ * Copyright 2002-2008, 2010, 2012-2015, 2017, 2021, 2023-2024 Andrew Wood
  *
  * License GPLv3+: GNU GPL version 3 or later; see `docs/COPYING'.
  */
@@ -95,14 +95,16 @@ static void pv_crs_open_lockfile(pvstate_t state, int fd)
 		return;
 	}
 
+	tmpdir = (char *) getenv("TMPDIR"); /* flawfinder: ignore */
+	if ((NULL == tmpdir) || ('\0' == tmpdir[0]))
+		tmpdir = (char *) getenv("TMP");	/* flawfinder: ignore */
+	if ((NULL == tmpdir) || ('\0' == tmpdir[0]))
+		tmpdir = "/tmp";
+
 	/*
-	 * We used to look at the TMPDIR or TMP environment variables to
-	 * override the temporary directory, but this leads to less
-	 * predictable behaviour, and flawfinder points out that relying on
-	 * environment variables in this way is not safe.  So the lock
-	 * directory is hard-coded to "/tmp" now (Sep 2023).
+	 * flawfinder rationale: null and zero-size values of $TMPDIR and
+	 * $TMP are rejected, and the destination buffer is bounded.
 	 */
-	tmpdir = "/tmp";
 
 	memset(state->cursor.lock_file, 0, PV_SIZEOF_CRS_LOCK_FILE);
 	(void) pv_snprintf(state->cursor.lock_file,
@@ -293,7 +295,7 @@ static int pv_crs_get_ypos(int terminalfd)
 	}
 #endif				/* !CURSOR_ANSWERBACK_BYTE_BY_BYTE */
 
-	ypos = (int) pv_getnum_count(cpr + 2);
+	ypos = (int) pv_getnum_count(cpr + 2, false);
 
 	if (0 != tcsetattr(terminalfd, TCSANOW | TCSAFLUSH, &old_tty)) {
 		debug("%s: %s", "tcsetattr (2) failed", strerror(errno));
